function logPr = compute_posterior(r,gam,delta02,psi,alpha,nu,p,y);

%------------------------------------------------------------------
% This function compute the probability (up to a normalization)
%       of having the MC state R according to the posterior 
%       of interest
% 
% INPUT
%       r       : the MC state for the matrix R
%       gam     : gam parameter
%       delta02 : delta02 parameter
%       psi     : psi parameter
%       alpha   : alpha parameter
%       nu      : nu parameter
%       p       : model order array
%       y       : the signal to be segmented
%
% OUTPUT
%       logPr : the log of the probability
%
%------------------------------------------------------------------


global J N pmax Tepsilon
global Tab_pfact

for j=1:2^J
    tmp = r(:,1:N-1)-Tepsilon(:,j)*ones(1,N-1);
    S(j) = length(find(sum(abs(tmp),1)==0));
end

% number of ruptures in each sequence
K = sum(r,2);
Kmax = max(K);

% length of each segment in each sequence
n = zeros(J,Kmax);
rtraf=[ones(J,1) r];

logPr =0;

% computation
logPr = logPr + sum(gammaln(S+alpha));

C_psi     = sum(psi.^(0:pmax)./Tab_pfact);

for j=1:J
    n(j,1:K(j)) = diff(find(rtraf(j,:)==1));
    InstantRupt(j,1:K(j)+1) = [0 find(r(j,:)==1)];
    for k=1:K(j)
        % computation of M_jk et T_jk
        [T2_jk det_M_jk ] = compute_TM(InstantRupt(j,k),InstantRupt(j,k+1),p(j,k),delta02,y(j,:));
        logPr = logPr + (nu/2)*log(gam) + gammaln(n(j,k)/2+nu/2) - gammaln(nu/2) ...
                      - (n(j,k)/2+nu/2)*log(gam+T2_jk)+1/2*log(det_M_jk) ...
                      - log(C_psi) + p(j,k) * log(psi) - sum(log(1:p(j,k))) ...
                      -(p(j,k)/2)*log(delta02);
    end
end
