function [r_out p_out] = sample_r(r,p,gam,delta02,psi,alpha,nu,xi,beta,mu,rho,y,step);

%------------------------------------------------------------------
% This function allows to sample the indicator matrix R
%       according to f(r|gam,delta02,alpha,nu,xi,beta,y)
% 
% INPUT
%       r       : the current state of the matrix R
%       p       : the current states of the AR model orders
%       gam     : the current state of the gam parameter
%       delta02 : the current state of the gam parameter
%       psi     : psi parameter
%       alpha   : alpha parameter
%       nu      : nu parameter
%       xi      : xi parameter
%       beta    : nu parameter
%       mu      : mu parameter
%       rho     : rho parameter
%       y       : the signal to be segmented
%
% OUTPUT
%       r_out : the new state of the matrix R
%
%------------------------------------------------------------------


global J N pmax Tepsilon

Kmax = 50;

valeurs = 1:2^J;
probas = zeros(1,2^J);
K = sum(r,2);

for i=randperm(floor((N-1)/step))*step;
    
   % computation of the 2^J probabilities P(r_i = epsilon|...)
    for config = 1:2^J
        
        % GENERATION OF THE CANDIDAT R_STAR
        r_star = r;
        r_star(:,i) = Tepsilon(:,config);;
        
        
        % GENERATION OF THE CANDIDAT R_STAR
        p_star = zeros(1,J,Kmax);
        
        for j=1:J
            % looking for the ruptures for the current state
            InstantRupt_j = [0 find(r(j,:)==1)];
            K_j = length(InstantRupt_j)-1;
            p_j = p(j,1:K_j);

            % looking for the ruptures for the candidate
            InstantRupt_j_star = [0 find(r_star(j,:)==1)];
            K_j_star = length(InstantRupt_j_star)-1;
            p_j_star = zeros(1,K_j_star);

            % kind of move
            mouv = r_star(j,i)-r(j,i);
            switch mouv
                case 1
                    % segment splitting
                    k_s = min(find(InstantRupt_j>i))-1;
                    p_j_star(1,1:k_s) = p_j(1,1:k_s);
                    p_j_star(k_s) = gen_discrete(1:p_j(k_s),ones(1,p_j(k_s)),1,1);
                    p_j_star(k_s+1) = max([1 p_j(k_s )-p_j_star(k_s)]);
                    if K_j>1
                        p_j_star(k_s + 2:K_j_star) = p_j(k_s+1:K_j);
                    end
                case -1
                    % segment merging
                    k_s = find(InstantRupt_j==i)-1;
                    p_j_star(1,1:k_s) = p_j(1,1:k_s);
                    p_j_star(k_s) = min([p_j(k_s) + p_j(k_s+1) pmax]);
                    if K_j_star>1
                        p_j_star((k_s + 1):K_j_star) = p_j((k_s+2):K_j);
                    end
                case 0
                    p_j_star = p_j;
            end
            p_star(1,j,1:K_j_star) = p_j_star(1:K_j_star);
        end

        Pr(config) = compute_posterior(r_star,gam,delta02,psi,alpha,nu,reshape(p_star,J,Kmax),y);
        Tab_p_star(config,:,:) = p_star;
        
    end
    
    % strategy to avoid overfloat
    Prmax = max(Pr);
    probas=exp(Pr-Prmax);
    probas = probas/sum(probas);
    
     % the new state is drawed according the 2^J probabilities
    x = gen_discrete(valeurs,probas,1,1);
    r(:,i)=Tepsilon(:,x);
    p=reshape(Tab_p_star(x,:,:),J,Kmax);
    
    
end
Kmax = max(sum(r,2));
r_out = r;
p_out = p(:,1:Kmax);
