function [Tab_r, Tab_K, Tab_p] = segmentation(y, Nmc, step)

%------------------------------------------------------------------
% JOINT SEGMENTATION PROCEDURE FOR AR PROCESSES WITH UNKNOWN
% AUTOREGRESSIVE MODEL ORDERS
% by N. DOBIGEON and J.-Y. TOURNERET 
% IRIT/ENSEEIHT/TSA - France - 2005
% 
% INPUT
%       y    : the signal to be segmented
%       p    : order of the AR processes
%       Nmc   : number of MCMC iterations
%       step : Sampling step. By default equal to 1. 
%              Can be increased to accelerate the procedure
%
% OUTPUT
%       Tab_r : the samples R(t) generated by the procedure
%       Tab_K : the corresponding samples K(t)
%
%------------------------------------------------------------------   
    
global J N pmax Tepsilon p_0
global Tab_pfact
global Tab_vect_i

% signals parameters
% J = number of sequence
% N = length of the signal
[ J N ] = size(y);

% BEGINNING OF THE SEGMENTATION
disp(' ');
disp('BEGINNING OF THE SEGMENTATION');


% initialization of the parameters

    % AR model order
    pmax = 20;

    r = [zeros(J,N-1) ones(J,1)];
    sigma2 = 5;
    a = 5;
    p = zeros(J,1)+1;
    
% computation of the factorials p_i! for i =0:pmax;
for pi=0:pmax
    Tab_pfact(pi+1) = factorial(pi);
end

    
% initialization of the hyperparameters

    % hyperparameters of f(r|P)
    P = ones(1,2^J); P = P/sum(P);
    
    % hyperparameters of f(sigma2|nu, gam)
    nu = 2;
    gam = 2;

    % hyperparameters of f(a|sigma2, delta02, p)
    delta02 = 1;
    
    % hyperparameters of f(p|psi)
    psi = mean(p);

    
% initialization of the hyper-hyperparamtres
    
    % hyper-hyperparamtres of f(P|alpha)
    alpha = ones(1,2^J);    % fixe
     
    % hyper-hyperparamtres of f(delta02|zeta, beta)
    beta = 100;             % fixe
    xi = 1;                 % fixe
    
    % hyper-hyperparamtres of f(psi|mu, rho)
    mu = 1;                 % fixe
    rho = 1/100;             % fixe

    
% other parameters
    
    % proba of birth for the AR model orders
    % proba_b = P[p_k -> p_k + 1];
    proba_b = [1/2 ones(1,pmax-2)*1/3 0];
    
    % proba of death for the AR model orders
    % proba_d = P[p_k -> p_k - 1];
    proba_d = [0 ones(1,pmax-2)*1/3 1/2];


    
% Tepsilon : all the abrupt change configurations
    eps_str=[];
    for i = 1:2^J
        eps_str = [eps_str' dec2bin(i-1,J)']';
    end
    for i = 1:2^J
        for j = 1:J
            Tepsilon(j,i) = strcmp(eps_str(i,j),'1');
        end
    end
    clear eps_str

% initialization of the AR's with pmax 0's
y = [zeros(J,pmax) y];
Kmax = 20;

% output : MCMC states
Tab_r = zeros(J,N,Nmc);
Tab_K = zeros(J,Nmc);
Tab_p = zeros(J,Kmax,Nmc);
Tab_P = zeros(2^J,Nmc);

	
% h = waitbar(0,['Segmentation...'],'CreateCancelBtn','closereq', 'name', 'Mthode "INIT"');
% tic

for m_compt = 1:Nmc
    m_compt
    % waitbar(m_compt/Nmc,h)

    % GENERATION OF R ACCORDING TO f(r|...)
        
        % pas d'chantillonnage
        %p = zeros(J,Kmax) + 5;
        [r p] = sample_r(r,p,gam,delta02,psi,alpha,nu,xi,beta,mu,rho,y,step);
        K = sum(r,2);
        Tab_r(:,:,m_compt) = r;
        Kmax=max(sum(r,2));
        Tab_K(:,m_compt) = K;
    
    % GENERATION OF p ACCORDING TO f(p|...) : REVERSIBLE JUMPS
        p = sample_pjk(r,p,gam,delta02,psi,nu,proba_b,proba_d,y);
        Tab_p(:,1:Kmax,m_compt) =p ;
        
    % GENERATION OF (gam,delta02) ACCORDING TO f(gam,sigma2|...)

        [gam delta02] = sample_gam_delta02(r,p,gam,delta02,nu,xi,beta,y);
               
    % GENERATION OF psi ACCORDING TO f(psi|...)
    
        psi = sample_psi(psi,K,p,mu,rho);

    % OPTIONNEL : GENERATION DE P SUIVANT f(P,sigma2|...)

    generer_P = 0;
    if generer_P==1
        P = sample_Peps(r,alpha);
    end;
end

% close(h)

%t_1 = toc;
% END OF THE SEGMENTATION

disp('END OF THE SEGMENTATION');